package com.emato.cus.supervise.config.ds.third;

import com.emato.cus.supervise.config.ds.second.SecondMapperConfig;
import com.emato.cus.supervise.config.ds.second.SecondMybatisConfigProperties;
import com.emato.cus.supervise.util.YmlUtils;
import com.google.common.base.Joiner;
import com.google.common.collect.ImmutableList;
import org.mybatis.spring.mapper.MapperScannerConfigurer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;


/**
 * Mybatis Mapper接口扫描配置
 *
 * @author Scott Chen
 * @date 2017/4/23
 */
@Configuration
public class ThirdMapperConfig {
    private static final Logger logger = LoggerFactory.getLogger(ThirdMapperConfig.class);

    @Bean
    public MapperScannerConfigurer thirdMapperScannerConfigurer() {
        MapperScannerConfigurer mapperScannerConfigurer = new MapperScannerConfigurer();
        //Mapper接口包
        mapperScannerConfigurer.setBasePackage(mapperPackageByYml());
        //要使用的数据源
        mapperScannerConfigurer.setSqlSessionTemplateBeanName("thirdSqlSessionTemplate");
        return mapperScannerConfigurer;
    }

    /**
     * 添加要扫描的Mapper接口包
     * 以逗号分隔的字符串
     *
     * @return
     */
    private String mapperPackageByYml() {
        String path = ThirdMybatisConfigProperties.MYBATIS_MAPPER_CONFIG_YML_PATH;
        logger.debug("yml: {}", path);

        String key = "mybatis.third.mapper-scanner-package";
        return YmlUtils.instance().getValue(key, path);
    }

}
